import { addListener, append, assign, createElement, detachNode, getSpreadUpdate, init, insert, proto, reinsertChildren, removeListener, setAttributes, callAll, createFragment, createText, setData, setStyle } from './shared.mjs';

const regex = /%s/gi;

function processClasses(classes, userClasses) {
    if (!userClasses) {
        return classes.join(" ");
    }
    if (Array.isArray(userClasses)) {
        userClasses = userClasses.join(" ");
    }
    if (!regex.test(userClasses)) {
        return userClasses+" "+classes.join(" ");
    }
    return userClasses.replace(regex, classes.join(" "));
}

/* src/Icon.html generated by Svelte v2.9.11 */

function attrs(attributes) {
    let result = Object.assign({"aria_hidden": "true"}, attributes);
    let classes = ["material-icons"];
    delete result.attrs;
    result["class"] = processClasses(classes, result["class"]);
    return result;
}
var methods = {
	getElement() {
		return this.refs.icon;
	}
};

function create_main_fragment(component, ctx) {
	var i, slot_content_default = component._slotted.default;

	function click_handler(event) {
		component.fire("click", event);
	}

	var i_levels = [
		ctx.attrs
	];

	var i_data = {};
	for (var i_1 = 0; i_1 < i_levels.length; i_1 += 1) {
		i_data = assign(i_data, i_levels[i_1]);
	}

	return {
		c() {
			i = createElement("i");
			addListener(i, "click", click_handler);
			setAttributes(i, i_data);
		},

		m(target, anchor) {
			insert(target, i, anchor);

			if (slot_content_default) {
				append(i, slot_content_default);
			}

			component.refs.icon = i;
		},

		p(changed, ctx) {
			setAttributes(i, getSpreadUpdate(i_levels, [
				(changed.attrs) && ctx.attrs
			]));
		},

		d(detach) {
			if (detach) {
				detachNode(i);
			}

			if (slot_content_default) {
				reinsertChildren(i, slot_content_default);
			}

			removeListener(i, "click", click_handler);
			if (component.refs.icon === i) component.refs.icon = null;
		}
	};
}

function Icon(options) {
	init(this, options);
	this.refs = {};
	this._state = assign({}, options.data);
	this._recompute({  }, this._state);
	this._intro = true;

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Icon.prototype, proto);
assign(Icon.prototype, methods);

Icon.prototype._recompute = function _recompute(changed, state) {
	if (this._differs(state.attrs, (state.attrs = attrs(state)))) changed.attrs = true;
};

/* src/GridListTile.html generated by Svelte v2.9.11 */

function create_main_fragment$1(component, ctx) {
	var li, div, text_1;

	function select_block_type(ctx) {
		if (ctx.bgImage) return create_if_block;
		return create_if_block_1;
	}

	var current_block_type = select_block_type(ctx);
	var if_block = current_block_type(component, ctx);

	var if_block_1 = (ctx.title) && create_if_block_2(component, ctx);

	return {
		c() {
			li = createElement("li");
			div = createElement("div");
			if_block.c();
			text_1 = createText("\n  ");
			if (if_block_1) if_block_1.c();
			div.className = "mdc-grid-tile__primary";
			li.className = "mdc-grid-tile";
		},

		m(target, anchor) {
			insert(target, li, anchor);
			append(li, div);
			if_block.m(div, null);
			append(li, text_1);
			if (if_block_1) if_block_1.m(li, null);
		},

		p(changed, ctx) {
			if (current_block_type === (current_block_type = select_block_type(ctx)) && if_block) {
				if_block.p(changed, ctx);
			} else {
				if_block.d(1);
				if_block = current_block_type(component, ctx);
				if_block.c();
				if_block.m(div, null);
			}

			if (ctx.title) {
				if (if_block_1) {
					if_block_1.p(changed, ctx);
				} else {
					if_block_1 = create_if_block_2(component, ctx);
					if_block_1.c();
					if_block_1.m(li, null);
				}
			} else if (if_block_1) {
				if_block_1.d(1);
				if_block_1 = null;
			}
		},

		d(detach) {
			if (detach) {
				detachNode(li);
			}

			if_block.d();
			if (if_block_1) if_block_1.d();
		}
	};
}

// (3:4) {#if bgImage}
function create_if_block(component, ctx) {
	var div;

	return {
		c() {
			div = createElement("div");
			div.className = "mdc-grid-tile__primary-content";
			setStyle(div, "background-image", "url(" + ctx.src + ")");
		},

		m(target, anchor) {
			insert(target, div, anchor);
		},

		p(changed, ctx) {
			if (changed.src) {
				setStyle(div, "background-image", "url(" + ctx.src + ")");
			}
		},

		d(detach) {
			if (detach) {
				detachNode(div);
			}
		}
	};
}

// (5:4) {:else}
function create_if_block_1(component, ctx) {
	var img;

	return {
		c() {
			img = createElement("img");
			img.className = "mdc-grid-tile__primary-content";
			img.src = ctx.src;
			img.alt = ctx.title;
		},

		m(target, anchor) {
			insert(target, img, anchor);
		},

		p(changed, ctx) {
			if (changed.src) {
				img.src = ctx.src;
			}

			if (changed.title) {
				img.alt = ctx.title;
			}
		},

		d(detach) {
			if (detach) {
				detachNode(img);
			}
		}
	};
}

// (11:4) {#if icon}
function create_if_block_3(component, ctx) {
	var text;

	var icon_initial_data = {
	 	class: "mdc-grid-tile__icon material-icons"
	 };
	var icon = new Icon({
		root: component.root,
		store: component.store,
		slots: { default: createFragment() },
		data: icon_initial_data
	});

	return {
		c() {
			text = createText(ctx.icon);
			icon._fragment.c();
		},

		m(target, anchor) {
			append(icon._slotted.default, text);
			icon._mount(target, anchor);
		},

		p(changed, ctx) {
			if (changed.icon) {
				setData(text, ctx.icon);
			}
		},

		d(detach) {
			icon.destroy(detach);
		}
	};
}

// (15:4) {#if supportText}
function create_if_block_4(component, ctx) {
	var span, text;

	return {
		c() {
			span = createElement("span");
			text = createText(ctx.supportText);
			span.className = "mdc-grid-tile__support-text";
		},

		m(target, anchor) {
			insert(target, span, anchor);
			append(span, text);
		},

		p(changed, ctx) {
			if (changed.supportText) {
				setData(text, ctx.supportText);
			}
		},

		d(detach) {
			if (detach) {
				detachNode(span);
			}
		}
	};
}

// (9:2) {#if title}
function create_if_block_2(component, ctx) {
	var span, text, span_1, text_1, text_2;

	var if_block = (ctx.icon) && create_if_block_3(component, ctx);

	var if_block_1 = (ctx.supportText) && create_if_block_4(component, ctx);

	return {
		c() {
			span = createElement("span");
			if (if_block) if_block.c();
			text = createText("\n    ");
			span_1 = createElement("span");
			text_1 = createText(ctx.title);
			text_2 = createText("\n    ");
			if (if_block_1) if_block_1.c();
			span_1.className = "mdc-grid-tile__title";
			span.className = "mdc-grid-tile__secondary";
		},

		m(target, anchor) {
			insert(target, span, anchor);
			if (if_block) if_block.m(span, null);
			append(span, text);
			append(span, span_1);
			append(span_1, text_1);
			append(span, text_2);
			if (if_block_1) if_block_1.m(span, null);
		},

		p(changed, ctx) {
			if (ctx.icon) {
				if (if_block) {
					if_block.p(changed, ctx);
				} else {
					if_block = create_if_block_3(component, ctx);
					if_block.c();
					if_block.m(span, text);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}

			if (changed.title) {
				setData(text_1, ctx.title);
			}

			if (ctx.supportText) {
				if (if_block_1) {
					if_block_1.p(changed, ctx);
				} else {
					if_block_1 = create_if_block_4(component, ctx);
					if_block_1.c();
					if_block_1.m(span, null);
				}
			} else if (if_block_1) {
				if_block_1.d(1);
				if_block_1 = null;
			}
		},

		d(detach) {
			if (detach) {
				detachNode(span);
			}

			if (if_block) if_block.d();
			if (if_block_1) if_block_1.d();
		}
	};
}

function GridListTile(options) {
	init(this, options);
	this._state = assign({}, options.data);
	this._intro = true;

	if (!options.root) {
		this._oncreate = [];
		this._beforecreate = [];
		this._aftercreate = [];
	}

	this._fragment = create_main_fragment$1(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);

		this._lock = true;
		callAll(this._beforecreate);
		callAll(this._oncreate);
		callAll(this._aftercreate);
		this._lock = false;
	}
}

assign(GridListTile.prototype, proto);

export default GridListTile;
