import { append, assign, assignTrue, callAll, createElement, detachNode, getSpreadUpdate, init, insert, proto, reinsertChildren, setAttributes } from './shared.mjs';

const regex = /%s/gi;

function processClasses(classes, userClasses) {
    if (!userClasses) {
        return classes.join(" ");
    }
    if (Array.isArray(userClasses)) {
        userClasses = userClasses.join(" ");
    }
    if (!regex.test(userClasses)) {
        return userClasses+" "+classes.join(" ");
    }
    return userClasses.replace(regex, classes.join(" "));
}

/* src/LayoutGridCell.html generated by Svelte v2.9.11 */

function attrs(attributes) {
    let result = Object.assign({}, attributes);
    let cls ="mdc-layout-grid__cell";
    let classes = [cls];
    if (result.cols) {
        classes.push(cls+"--span-"+result.cols);
    }
    if (result.desktopCols) {
        classes.push(cls+"--span-"+result.desktopCols+"-desktop");
    }
    if (result.tabletCols) {
        classes.push(cls+"--span-"+result.tabletCols+"-tablet");
    }
    if (result.phoneCols) {
        classes.push(cls+"--span-"+result.phoneCols+"-mobile");
    }
    if (result.order) {
        classes.push(cls+"--order-"+result.order);
    }
    if (result.align) {
        classes.push(cls+"--align-"+result.align);
    }
    if (result.fixedColumnWidth) {
        classes.push(cls+"--fixed-column-width");
    }
    delete result.cols;
    delete result.desktopCols;
    delete result.tabletCols;
    delete result.phoneCols;
    delete result.order;
    delete result.fixedColumnWidth;
    delete result.attrs;
    result["class"] = processClasses(classes, result["class"]);
    return result;
}
function onstate({current}) {
    for(let [key, min, max] of [["cols", 1, 12], ["desktopCols", 1, 12], ["tabletCols", 1, 8], ["phoneCols", 1, 4], ["order", 1, 2]]) {
        let value = parseInt(current[key]);
        if (!value) {
            continue;
        }
        if (isNaN(value) || (typeof current[key] === "number" && value !== current[key])) {
            throw new Error(`"${key}" should be an integer`);
        }
        if (value < min) {
            throw new Error(`"${key}" should be bigger or equal to ${min}, but it's only ${value}`);
        }
        if (value > max) {
            throw new Error(`"${key}" should be less or equal to ${max}, but it's only ${value}`);
        }
    }
    if (current.align && ['top', 'middle', 'botton'].includes(current.align)) {
        throw new Error(`Invalid value for "align" attribute: "${current.align}", should be "top", "middle" or "bottom"`);
    }
}
function create_main_fragment(component, ctx) {
	var div, slot_content_default = component._slotted.default;

	var div_levels = [
		ctx.attrs
	];

	var div_data = {};
	for (var i = 0; i < div_levels.length; i += 1) {
		div_data = assign(div_data, div_levels[i]);
	}

	return {
		c() {
			div = createElement("div");
			setAttributes(div, div_data);
		},

		m(target, anchor) {
			insert(target, div, anchor);

			if (slot_content_default) {
				append(div, slot_content_default);
			}
		},

		p(changed, ctx) {
			setAttributes(div, getSpreadUpdate(div_levels, [
				(changed.attrs) && ctx.attrs
			]));
		},

		d(detach) {
			if (detach) {
				detachNode(div);
			}

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		}
	};
}

function LayoutGridCell(options) {
	init(this, options);
	this._state = assign({}, options.data);
	this._recompute({  }, this._state);
	this._intro = true;

	this._handlers.state = [onstate];

	this._slotted = options.slots || {};

	if (!options.root) {
		this._oncreate = [];
	}

	this.slots = {};

	this._fragment = create_main_fragment(this, this._state);

	this.root._oncreate.push(() => {
		onstate.call(this, { changed: assignTrue({}, this._state), current: this._state });
		this.fire("update", { changed: assignTrue({}, this._state), current: this._state });
	});

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);

		callAll(this._oncreate);
	}
}

assign(LayoutGridCell.prototype, proto);

LayoutGridCell.prototype._recompute = function _recompute(changed, state) {
	if (this._differs(state.attrs, (state.attrs = attrs(state)))) changed.attrs = true;
};

export default LayoutGridCell;
