import { append, assign, createComment, createElement, createText, detachNode, getSpreadUpdate, init, insert, noop, proto, reinsertBetween, reinsertChildren, setAttribute, setAttributes, setData } from './shared.mjs';

const regex = /%s/gi;

function processClasses(classes, userClasses) {
    if (!userClasses) {
        return classes.join(" ");
    }
    if (Array.isArray(userClasses)) {
        userClasses = userClasses.join(" ");
    }
    if (!regex.test(userClasses)) {
        return userClasses+" "+classes.join(" ");
    }
    return userClasses.replace(regex, classes.join(" "));
}

/* src/ListItem.html generated by Svelte v2.9.11 */

function attrs(attributes) {
    let result = Object.assign({}, attributes);
    let cls ="mdc-list-item";
    let classes = [cls];
    for (let key of ["selected", "activated"]) {
        if (result[key]) {
            classes.push(cls+"--"+key);
        }
        delete result[key];
    }
    for (let key of ["primaryText", "secondText", "showGraphic", "showMeta", "attrs"])  {
        delete result[key];
    }
    result["class"] = processClasses(classes, result["class"]);
    return result;
}
function data() {
    return {
        showMeta: false,
        showGraphic: false
    }
}
function create_main_fragment(component, ctx) {
	var li, text, text_1;

	var if_block = (ctx.showGraphic) && create_if_block(component, ctx);

	function select_block_type(ctx) {
		if (ctx.primaryText) return create_if_block_1;
		return create_if_block_3;
	}

	var current_block_type = select_block_type(ctx);
	var if_block_1 = current_block_type(component, ctx);

	var if_block_2 = (ctx.showMeta) && create_if_block_4(component, ctx);

	var li_levels = [
		ctx.attrs
	];

	var li_data = {};
	for (var i = 0; i < li_levels.length; i += 1) {
		li_data = assign(li_data, li_levels[i]);
	}

	return {
		c() {
			li = createElement("li");
			if (if_block) if_block.c();
			text = createText("\n    ");
			if_block_1.c();
			text_1 = createText("\n    ");
			if (if_block_2) if_block_2.c();
			setAttributes(li, li_data);
		},

		m(target, anchor) {
			insert(target, li, anchor);
			if (if_block) if_block.m(li, null);
			append(li, text);
			if_block_1.m(li, null);
			append(li, text_1);
			if (if_block_2) if_block_2.m(li, null);
		},

		p(changed, ctx) {
			if (ctx.showGraphic) {
				if (!if_block) {
					if_block = create_if_block(component, ctx);
					if_block.c();
					if_block.m(li, text);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}

			if (current_block_type === (current_block_type = select_block_type(ctx)) && if_block_1) {
				if_block_1.p(changed, ctx);
			} else {
				if_block_1.d(1);
				if_block_1 = current_block_type(component, ctx);
				if_block_1.c();
				if_block_1.m(li, text_1);
			}

			if (ctx.showMeta) {
				if (!if_block_2) {
					if_block_2 = create_if_block_4(component, ctx);
					if_block_2.c();
					if_block_2.m(li, null);
				}
			} else if (if_block_2) {
				if_block_2.d(1);
				if_block_2 = null;
			}

			setAttributes(li, getSpreadUpdate(li_levels, [
				(changed.attrs) && ctx.attrs
			]));
		},

		d(detach) {
			if (detach) {
				detachNode(li);
			}

			if (if_block) if_block.d();
			if_block_1.d();
			if (if_block_2) if_block_2.d();
		}
	};
}

// (2:4) {#if showGraphic}
function create_if_block(component, ctx) {
	var span, slot_content_graphic = component._slotted.graphic;

	return {
		c() {
			span = createElement("span");
			setAttribute(span, "role", "presentation");
			span.className = "mdc-list-item__graphic";
		},

		m(target, anchor) {
			insert(target, span, anchor);

			if (slot_content_graphic) {
				append(span, slot_content_graphic);
			}
		},

		d(detach) {
			if (detach) {
				detachNode(span);
			}

			if (slot_content_graphic) {
				reinsertChildren(span, slot_content_graphic);
			}
		}
	};
}

// (10:6) {#if secondText}
function create_if_block_2(component, ctx) {
	var span, text;

	return {
		c() {
			span = createElement("span");
			text = createText(ctx.secondText);
			span.className = "mdc-list-item__secondary-text";
		},

		m(target, anchor) {
			insert(target, span, anchor);
			append(span, text);
		},

		p(changed, ctx) {
			if (changed.secondText) {
				setData(text, ctx.secondText);
			}
		},

		d(detach) {
			if (detach) {
				detachNode(span);
			}
		}
	};
}

// (7:4) {#if primaryText}
function create_if_block_1(component, ctx) {
	var span, text, text_1;

	var if_block = (ctx.secondText) && create_if_block_2(component, ctx);

	return {
		c() {
			span = createElement("span");
			text = createText(ctx.primaryText);
			text_1 = createText("\n      ");
			if (if_block) if_block.c();
			span.className = "mdc-list-item__text";
		},

		m(target, anchor) {
			insert(target, span, anchor);
			append(span, text);
			append(span, text_1);
			if (if_block) if_block.m(span, null);
		},

		p(changed, ctx) {
			if (changed.primaryText) {
				setData(text, ctx.primaryText);
			}

			if (ctx.secondText) {
				if (if_block) {
					if_block.p(changed, ctx);
				} else {
					if_block = create_if_block_2(component, ctx);
					if_block.c();
					if_block.m(span, null);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}
		},

		d(detach) {
			if (detach) {
				detachNode(span);
			}

			if (if_block) if_block.d();
		}
	};
}

// (16:4) {:else}
function create_if_block_3(component, ctx) {
	var slot_content_default = component._slotted.default, slot_content_default_before, slot_content_default_after;

	return {
		c: noop,

		m(target, anchor) {
			if (slot_content_default) {
				insert(target, slot_content_default_before || (slot_content_default_before = createComment()), anchor);
				insert(target, slot_content_default, anchor);
				insert(target, slot_content_default_after || (slot_content_default_after = createComment()), anchor);
			}
		},

		p: noop,

		d(detach) {
			if (slot_content_default) {
				reinsertBetween(slot_content_default_before, slot_content_default_after, slot_content_default);
				detachNode(slot_content_default_before);
				detachNode(slot_content_default_after);
			}
		}
	};
}

// (19:4) {#if showMeta}
function create_if_block_4(component, ctx) {
	var span, slot_content_meta = component._slotted.meta;

	return {
		c() {
			span = createElement("span");
			setAttribute(span, "role", "presentation");
			span.className = "mdc-list-item__meta";
		},

		m(target, anchor) {
			insert(target, span, anchor);

			if (slot_content_meta) {
				append(span, slot_content_meta);
			}
		},

		d(detach) {
			if (detach) {
				detachNode(span);
			}

			if (slot_content_meta) {
				reinsertChildren(span, slot_content_meta);
			}
		}
	};
}

function ListItem(options) {
	init(this, options);
	this._state = assign(data(), options.data);
	this._recompute({  }, this._state);
	this._intro = true;

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ListItem.prototype, proto);

ListItem.prototype._recompute = function _recompute(changed, state) {
	if (this._differs(state.attrs, (state.attrs = attrs(state)))) changed.attrs = true;
};

export default ListItem;
