import { append, assign, createElement, detachNode, getSpreadUpdate, init, insert, proto, reinsertChildren, setAttributes } from './shared.mjs';

const regex = /%s/gi;

function processClasses(classes, userClasses) {
    if (!userClasses) {
        return classes.join(" ");
    }
    if (Array.isArray(userClasses)) {
        userClasses = userClasses.join(" ");
    }
    if (!regex.test(userClasses)) {
        return userClasses+" "+classes.join(" ");
    }
    return userClasses.replace(regex, classes.join(" "));
}

/* src/Typography.html generated by Svelte v2.9.11 */

var validTypes = ["caption", "button", "overline"];
for (let i=1; i < 7; ++i) {
    if (i < 3) {
        validTypes.push("body"+i);
        validTypes.push("subtitle"+i);
    }
    validTypes.push("headline"+i);
}
function attrs(attributes) {
    let result = Object.assign({}, attributes);
    let classes = ["mdc-mdc-typography"+(result.type?"--"+result.type : "")];
    if (result.type && !validTypes.includes(result.type)) {
        throw new Error(`Invalid type '${result.type}'}`);
    }
    delete result.type;
    delete result.attrs;
    result["class"] = processClasses(classes, result["class"]);
    return result;
}
function create_main_fragment(component, ctx) {
	var span, slot_content_default = component._slotted.default;

	var span_levels = [
		ctx.attrs
	];

	var span_data = {};
	for (var i_1 = 0; i_1 < span_levels.length; i_1 += 1) {
		span_data = assign(span_data, span_levels[i_1]);
	}

	return {
		c() {
			span = createElement("span");
			setAttributes(span, span_data);
		},

		m(target, anchor) {
			insert(target, span, anchor);

			if (slot_content_default) {
				append(span, slot_content_default);
			}
		},

		p(changed, ctx) {
			setAttributes(span, getSpreadUpdate(span_levels, [
				(changed.attrs) && ctx.attrs
			]));
		},

		d(detach) {
			if (detach) {
				detachNode(span);
			}

			if (slot_content_default) {
				reinsertChildren(span, slot_content_default);
			}
		}
	};
}

function Typography(options) {
	init(this, options);
	this._state = assign({}, options.data);
	this._recompute({  }, this._state);
	this._intro = true;

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Typography.prototype, proto);

Typography.prototype._recompute = function _recompute(changed, state) {
	if (this._differs(state.attrs, (state.attrs = attrs(state)))) changed.attrs = true;
};

export default Typography;
